<?php

/* * *************************************************************************************************** */

// Filter text fields
/* * *************************************************************************************************** */

function nimbus_filter_text($input) {
    global $allowedposttags;
    $output = wp_kses($input, $allowedposttags);
    return $output;
}

add_filter('nimbus_filter_text', 'nimbus_filter_text');


/* * *************************************************************************************************** */

// Filter Textareas
/* * *************************************************************************************************** */

function nimbus_filter_textarea($input) {
    $output = $input;
    return $output;
}

add_filter('nimbus_filter_textarea', 'nimbus_filter_textarea');


/* * *************************************************************************************************** */

// Filter Image
/* * *************************************************************************************************** */

// Allow .ico file extention

function nimbus_myme_types($mime_types) {
    $mime_types = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif' => 'image/gif',
        'png' => 'image/png',
        'bmp' => 'image/bmp',
        'ico' => 'image/x-icon',
        'tif|tiff' => 'image/tiff'
    );
    return $mime_types;
}

add_filter('upload_mimes', 'nimbus_myme_types', 1, 1);

function nimbus_filter_image($input) {
    $output = '';
    $filetype = wp_check_filetype($input);
    if ($filetype["ext"]) {
        $output = $input;
    }
    return $output;
}

add_filter('nimbus_filter_image', 'nimbus_filter_image');


/* * *************************************************************************************************** */

// Filter Select
/* * *************************************************************************************************** */

function nimbus_filter_select($input, $option) {
    $output = '';
    if (array_key_exists($input, $option['options'])) {
        $output = $input;
    }
    return $output;
}

add_filter('nimbus_filter_select', 'nimbus_filter_select', 10, 2);


/* * *************************************************************************************************** */

// Filter Radio
/* * *************************************************************************************************** */

function nimbus_filter_radio($input, $option) {
    $output = '';
    if (array_key_exists($input, $option['options'])) {
        $output = $input;
    }
    return $output;
}

add_filter('nimbus_filter_radio', 'nimbus_filter_radio', 10, 2);


/* * *************************************************************************************************** */

// Filter Checkbox
/* * *************************************************************************************************** */

function nimbus_filter_checkbox($input) {
    if ($input) {
        $output = "1";
    } else {
        $output = "0";
    }
    return $output;
}

add_filter('nimbus_filter_checkbox', 'nimbus_filter_checkbox');


/* * *************************************************************************************************** */

// Filter Multicheck
/* * *************************************************************************************************** */

function nimbus_filter_multicheck($input, $option) {
    $output = '';
    if (is_array($input)) {
        foreach ($option['options'] as $key => $value) {
            $output[$key] = "0";
        }
        foreach ($input as $key => $value) {
            if (array_key_exists($key, $option['options']) && $value) {
                $output[$key] = "1";
            }
        }
    }
    return $output;
}

add_filter('nimbus_filter_multicheck', 'nimbus_filter_multicheck', 10, 2);


/* * *************************************************************************************************** */
// Filter color
/* * *************************************************************************************************** */

add_filter('nimbus_filter_color', 'nimbus_filter_color');

function nimbus_filter_color($hex, $default = '') {
    if (nimbus_validate_hex($hex)) {
        return $hex;
    } else {
        return $default;
    }
}

/* * *************************************************************************************************** */

// Validate hex color
/* * *************************************************************************************************** */

function nimbus_validate_hex($hex) {
    $hex = trim($hex);
    /* Strip recognized prefixes. */
    if (0 === strpos($hex, '#')) {
        $hex = substr($hex, 1);
    } elseif (0 === strpos($hex, '%23')) {
        $hex = substr($hex, 3);
    }
    /* Regex match. */
    if (0 === preg_match('/^[0-9a-fA-F]{6}$/', $hex)) {
        return false;
    } else {
        return true;
    }
}

/* Typography */

function nimbus_filter_typography($input) {
    $output = wp_parse_args($input, array(
        'size' => '',
        'face' => '',
        'style' => '',
        'color' => ''
            ));

    $output['size'] = apply_filters('of_font_size', $output['size']);
    $output['face'] = apply_filters('of_font_face', $output['face']);
    $output['style'] = apply_filters('of_font_style', $output['style']);
    $output['color'] = apply_filters('nimbus_filter_color', $output['color']);

    return $output;
}

add_filter('nimbus_filter_typography', 'nimbus_filter_typography');

function nimbus_filter_font_size($value) {
    $recognized = of_recognized_font_sizes();
    $value = preg_replace('/px/', '', $value);
    if (in_array((int) $value, $recognized)) {
        return (int) $value;
    }
    return (int) apply_filters('of_default_font_size', $recognized);
}

add_filter('of_font_face', 'nimbus_filter_font_face');

function nimbus_filter_font_style($value) {
    $recognized = nimbus_font_styles();
    if (array_key_exists($value, $recognized)) {
        return $value;
    }
    return apply_filters('of_default_font_style', current($recognized));
}

add_filter('of_font_style', 'nimbus_filter_font_style');

function nimbus_filter_font_face($value) {
    global $NIMBUS_FONT_FACES;
    $recognized = $NIMBUS_FONT_FACES;
    if (array_key_exists($value, $recognized)) {
        return $value;
    }
    return apply_filters('of_default_font_face', current($recognized));
}

add_filter('of_font_face', 'nimbus_filter_font_face');




/* Font */

function nimbus_filter_font($input) {
    $output = wp_parse_args($input, array(
        'face' => '',
        'color' => ''
            ));

    $output['face'] = apply_filters('nimbus_font_font_face', $output['face']);
    $output['color'] = apply_filters('nimbus_filter_color', $output['color']);

    return $output;
}

add_filter('nimbus_filter_font', 'nimbus_filter_font');

function nimbus_font_font_face($value) {
    global $NIMBUS_FONT_FACES;
    $recognized = $NIMBUS_FONT_FACES;
    if (array_key_exists($value, $recognized)) {
        return $value;
    }
    return apply_filters('of_default_font_face', current($recognized));
}

add_filter('nimbus_font_font_face', 'nimbus_font_font_face');



/* Face */

function nimbus_filter_face($input) {
    $output = $input;
    return $output;
}

add_filter('nimbus_filter_face', 'nimbus_filter_face');

/**
 * Sanitize a color represented in hexidecimal notation.
 *
 * @param    string    Color in hexidecimal notation. "#" may or may not be prepended to the string.
 * @param    string    The value that this function should return if it cannot be recognized as a color.
 * @return   string
 *
 */
function nimbus_filter_hex($hex, $default = '') {
    if (nimbus_validate_hex($hex)) {
        return $hex;
    }
    return $default;
}

